@@ -121,6 +121,16 @@ buildStrataDF <- function(dataset) {
     }  # end domain cycle
     colnames(stratatot) <- toupper(colnames(stratatot))
     stratatot$DOM1 <- as.factor(stratatot$DOM1)
+    write.table(stratatot, "strata.txt", quote = FALSE, sep = "\t", 
+                dec = ".", row.names = FALSE)
+    stratatot <- read.delim("strata.txt")
+    options("scipen"=100)
+    for (i in (1:nvarY)) {
+      for (j in (1:nrow(stratatot))) {
+        stmt <- paste("stratatot$M",i,"[j] <- ifelse(stratatot$M",i,"[j] == 0,0.000000000000001,stratatot$M",i,"[j])",sep="")
+        eval(parse(text=stmt))
+      }
+    }
     write.table(stratatot, "strata.txt", quote = FALSE, sep = "\t", 
         dec = ".", row.names = FALSE)
     stratatot <- read.delim("strata.txt")
